.. _datamatrix:

DataMatrix and StateMatrix
====================================================================

.. autoclass:: fwdpy11.DataMatrix
   :members:

.. autoclass:: fwdpy11.StateMatrix
   :members:
